import * as React from "react";
import {ChangeEvent} from "react";
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../../stores/DashboardComponentStore";
import {TableCell} from "@material-ui/core";
import {InputField, useReadonlyContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {ScoreCardRowParameter} from "./ScoreCardSettings";

export type ScoreCardGoalSetterProps = {
    component: DashboardComponentModel;
    row: ScoreCardRowParameter;
    rowIndex: number;
}

export const ScoreCardGoalSetter: React.FunctionComponent<ScoreCardGoalSetterProps> = observer(({
                                                                                                    component,
                                                                                                    row,
                                                                                                    rowIndex
                                                                                                }) => {
    const readOnly = useReadonlyContext();

    const onChange = (event: ChangeEvent) => {
        const tmp = event.target?.name.split('.');
        const propName = tmp[tmp.length - 1];
        row[propName] = event.target?.value;
        component.handleChange(event);
    }

    // Add two empty columns on a divider row to keep the regular sizing
    if (row.row_type === 'divider') {
        return <>
            <TableCell style={{minWidth: '200px', maxWidth: '500px'}}/>
            <TableCell style={{minWidth: '200px', maxWidth: '500px'}}/>
        </>
    }

    return <>
        <TableCell>
            <InputField label={t`Min. Target Value`}
                        name={`parameters.rows[${rowIndex}].goal_minimum`}
                        value={row.goal_minimum || ''}
                        disabled={readOnly}
                        type={"number"}
                        inputProps={{min: 0}}
                        onChange={onChange}
                        hint={{
                            title: t`Min. Target`,
                            text: t`If a cell value is under this number, the cell background will appear red. Over this value (but under target) will appear in yellow.`
                        }}
            />
        </TableCell>
        <TableCell>
            <InputField label={t`Target Value`}
                        name={`parameters.rows[${rowIndex}].goal`}
                        value={row.goal || ''}
                        disabled={readOnly}
                        type={'number'}
                        onChange={onChange}
                        hint={{
                            title: t`Target`,
                            text: t`If a cell value is over this number, the cell background will appear green.`
                        }}
            />
        </TableCell>

    </>
})
