import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {makeStyles} from "@material-ui/core/styles";
import {PolarAreaChart} from "@rx-suite/ui";
import {useGraphOptions} from "../../../hooks/useGraphOptions";

export type DashboardComponentPolarAreaChartProps = {
    component: DashboardComponentModel
};

const useStyles = makeStyles(() => ({
    artificialMultiWrapper: {
        display: 'flex',
        flexDirection: 'row',
        width: '100%',
        height: '100%',
    }
}));

export const DashboardComponentPolarAreaChart: React.FunctionComponent<DashboardComponentPolarAreaChartProps> = observer(({component}) => {
    const classes = useStyles();
    const data = component.viewModel.data || {};
    const series = data.series || [{}];
    const options = useGraphOptions(component);

    if (component.isNew) {
        const fakeSeries = [Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10)]
        return <div className={classes.artificialMultiWrapper}><PolarAreaChart series={fakeSeries}
                                                                               key={JSON.stringify(fakeSeries)}
                                                                               options={{
                                                                                   ...options,
                                                                                   labels: ['A', 'B', 'C', 'D'],
                                                                                   colors: ['#DCDCDC', "#C0C0C0", "#808080", "#404040"]
                                                                               }}/></div>
    } else {
        return <div className={classes.artificialMultiWrapper}>
            {series.map((s: any) => <PolarAreaChart series={(s || {}).data || []}
                                                    key={JSON.stringify(s || {})}
                                                    options={options}/>
            )}
        </div>
    }
});
