import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {ScatterChart} from "@rx-suite/ui";
import {useGraphOptions} from "../../../hooks/useGraphOptions";

export type DashboardComponentScatterChartProps = {
    component: DashboardComponentModel
};

export const DashboardComponentScatterChart: React.FunctionComponent<DashboardComponentScatterChartProps> = observer(({component}) => {
    const series = component.viewModel.data.series || [];
    const options = useGraphOptions(component);

    if (component.isNew) {
        const fakeSeries = [{
            data: [Math.floor(Math.random() * 10), Math.floor(Math.random() * 10), Math.floor(Math.random() * 10)].map((v, i) => ({
                x: i + 1,
                y: v
            }))
        }];
        return <ScatterChart series={fakeSeries}
                             options={{
                                 ...options,
                                 colors: ['#DCDCDC']
                             }}
        />;
    } else {
        return <ScatterChart series={series}
                             options={options}/>;
    }
});
