import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {Button, Divider, Typography} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faUpload} from "@rx-suite/pro-solid-svg-icons";
import {Trans} from "@lingui/macro";
import {Conditional, IfFalse, IfTrue} from "@rx-suite/ui";

export type FileUploadProps = {
    onChange: (e: any) => void;
    fileName: string;
};

const useStyles = makeStyles(theme => ({
    root: {
        padding: '2px 4px',
        display: 'flex',
        alignItems: 'center',
        width: 400,
    },
    input: {
        marginLeft: 8,
        flex: 1,
    },
    iconButton: {
        marginLeft: theme.spacing(1),
        marginRight: theme.spacing(2)
    },
    divider: {
        width: 1,
        margin: theme.spacing(1),
        height: 28,
    },
}));

export const FileUpload: React.FunctionComponent<FileUploadProps> = observer(({onChange, fileName}) => {
    const classes = useStyles();

    const [uploading, setUploading] = React.useState(false);

    const onChangeHandler = React.useCallback((event) => {
        setUploading(true)
        if (event.target.files[0]) {
            if (parseFloat(event.target.files[0].size) > 262144000) {
                alert("File size must be no more than 25MB");
            } else {
                onChange(event);
            }
        }
        setUploading(false)
    }, [onChange]);

    return (
        <React.Fragment>
            <input
                className={classes.input}
                id="raised-button-file"
                multiple
                type="file"
                onChange={onChangeHandler}
                onClick={() => {
                    console.log('fired');
                    setUploading(true)
                }}
                hidden
            />
            <label htmlFor="raised-button-file">
                <Button component="span">
                    <FontAwesomeIcon icon={faUpload} className={classes.iconButton}/>
                    <Trans>Choose a file...</Trans>
                    <Conditional condition={fileName != ""}>
                        <IfTrue>
                            <Divider className={classes.divider}/>
                            <Typography component="span" variant="caption">
                                {fileName}
                            </Typography>
                        </IfTrue>
                        <IfFalse>
                            <Divider className={classes.divider}/>
                            <Conditional condition={uploading}>
                                <IfTrue>
                                    <Trans>Uploading...</Trans>
                                </IfTrue>
                            </Conditional>
                        </IfFalse>
                    </Conditional>
                </Button>
            </label>
        </React.Fragment>)
});