import {createStyles, Divider, makeStyles, Theme} from "@material-ui/core";
import {t} from "@lingui/macro";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {ModelSelect} from "@rx-suite/ui";
import {LabLayoutComponentModel} from "../../stores/LabLayoutComponentStore";
import {MachineGroupStore} from "../../stores/MachineGroupStore";

export type AlertGroupSelectProps = {
    model: LabLayoutComponentModel | undefined;
};

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        divider: {
            marginTop: theme.spacing(1),
            marginBottom: theme.spacing(1)
        }
    })
);

export const AlertGroupSelect: React.FunctionComponent<AlertGroupSelectProps> = observer(({model}) => {
    const classes = useStyles();

    const groupSelectOptions = React.useMemo(() => {
        return MachineGroupStore.models.map(g => {
            return {label: g.name, value: g.id}
        })
    }, [MachineGroupStore.models]);


    if (!model || !model.isAlertGroupComponent) {
        return null;
    }
//Select one or more machine group(s). If every machine of a group are in the error state, this error display will appear.
    return (
        <React.Fragment>
            <Divider className={classes.divider}/>
            <ModelSelect label={t`Machine Groups to Monitor`} name={'machine_group_ids'} options={groupSelectOptions}
                         multiple hint={{
                title: t`Machine Groups to Monitor`,
                text: t`Select one or more machine group(s). If every machine of a group are in the error state, this error display will appear.`
            }}/>
        </React.Fragment>
    )
});