module.exports = function (api) {
    var validEnv = ['development', 'test', 'production']
    var currentEnv = api.env()
    var isDevelopmentEnv = api.env('development')
    var isProductionEnv = api.env('production')
    var isTestEnv = api.env('test')

    if (!validEnv.includes(currentEnv)) {
        throw new Error(
            'Please specify a valid `NODE_ENV` or ' +
            '`BABEL_ENV` environment variables. Valid values are "development", ' +
            '"test", and "production". Instead, received: ' +
            JSON.stringify(currentEnv) +
            '.'
        )
    }

    let ignore = [/node_modules/];
    if(api.caller(caller => caller?.name === "lingui")) {
        ignore = undefined;
    }
    return {
        ignore: ignore,
        presets: [
            isTestEnv && [
                '@babel/preset-env',
                {
                    targets: {
                        node: 'current'
                    },
                    modules: 'commonjs'
                },
                '@babel/preset-react'
            ],
            (isProductionEnv || isDevelopmentEnv) && [
                '@babel/preset-env',
                {
                    forceAllTransforms: true,
                    useBuiltIns: 'entry',
                    corejs: 3,
                    modules: false,
                    exclude: ['transform-typeof-symbol']
                }
            ],
            [
                '@babel/preset-react',
                {
                    development: isDevelopmentEnv || isTestEnv,
                    useBuiltIns: true
                }
            ],
            '@babel/preset-typescript'
        ].filter(Boolean),
        plugins: [
            ["@babel/plugin-proposal-decorators", {"legacy": true}],
            ["macros", {}, 'babel-macros'],
            ["@babel/plugin-proposal-class-properties", {loose: true}],
            ["@babel/plugin-proposal-private-methods", { "loose": true }],
            ["@babel/plugin-proposal-private-property-in-object", { "loose": true }]
        ]
    }
}